@@ -6,7 +6,7 @@ from collections import defaultdict, deque, Sequence
 from .primitives import EMPTY
 from .types import is_seqcont
 from .funcs import partial
-from .funcmakers import wrap_mapper, wrap_selector
+from .funcmakers import wrap_mapper, wrap_selector, make_func
 
 
 __all__ = [
@@ -16,7 +16,7 @@ __all__ = [
     'concat', 'iconcat', 'chain', 'cat', 'icat', 'flatten', 'iflatten', 'mapcat', 'imapcat',
     'izip', 'interleave', 'interpose', 'distinct',
     'dropwhile', 'takewhile', 'split', 'split_at', 'split_by',
-    'group_by', 'count_by',
+    'group_by', 'group_by_keys', 'count_by',
     'partition', 'ipartition', 'chunks', 'ichunks', 'ipartition_by', 'partition_by',
     'with_prev', 'pairwise',
     'ireductions', 'reductions', 'isums', 'sums',
@@ -156,10 +156,26 @@ dropwhile = wrap_selector(dropwhile)
 takewhile = wrap_selector(takewhile)
 
 
-def distinct(seq):
+def distinct(seq, key=EMPTY):
     "Order preserving distinct"
+    return list(idistinct(seq, key))
+
+def idistinct(seq, key=EMPTY):
     seen = set()
-    return [x for x in seq if x not in seen and not seen.add(x)]
+    # check if key is supplied out of loop for efficiency
+    if key is EMPTY:
+        for item in seq:
+            if item not in seen:
+                seen.add(item)
+                yield item
+    else:
+        key = make_func(key)
+        for item in seq:
+            k = key(item)
+            if k not in seen:
+                seen.add(k)
+                yield item
+
 
 def isplit(pred, seq):
     a, b = tee(seq)
@@ -183,9 +199,6 @@ def split_by(pred, seq):
     return map(list, isplit_by(pred, seq))
 
 
-# NOTE: should I name it cluster? to distinguish from itertools.groupby
-#       or just group?
-# NOTE: should it return OrderedDict to preserve order of keys not just values?
 @wrap_mapper
 def group_by(f, seq):
     result = defaultdict(list)
@@ -193,6 +206,14 @@ def group_by(f, seq):
         result[f(item)].append(item)
     return result
 
+@wrap_mapper
+def group_by_keys(get_keys, seq):
+    result = defaultdict(list)
+    for item in seq:
+        for k in get_keys(item):
+            result[k].append(item)
+    return result
+
 @wrap_mapper
 def count_by(f, seq):
     result = defaultdict(int)
