@@ -1,4 +1,4 @@
-EMPTY = object()
+from .primitives import EMPTY
 
 
 def identity(x):
